@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.1.4";
+our $VERSION = "5.1.5";
 
 
 =head2 on_generate
@@ -198,8 +198,8 @@ sub on_generate
                                    } );
         }
 
-        open( my $handle, ">:encoding(UTF-8)", $out)
-            or die "Failed to open `$out' for writing: $!";
+        open( my $handle, ">:encoding(UTF-8)", $out ) or
+          die "Failed to open `$out' for writing: $!";
         print $handle $c->output();
         close($handle);
 
