@@ -27,7 +27,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.1.4";
+our $VERSION = "5.1.5";
 
 
 =head2 on_generate
@@ -69,11 +69,7 @@ sub on_generate
     #
     #  Load our HTML::Template file
     #
-    my $tmpl = "";
-    while ( my $line = <DATA> )
-    {
-        $tmpl .= $line;
-    }
+    my $tmpl = do {local $/; <DATA>};
     return unless ( length($tmpl) );
 
 
